``pants.datagram``
******************

.. automodule:: pants.datagram


``Datagram``
============

.. autoclass:: Datagram
    :members: listen, close, end, write, flush, on_read, on_write, on_listen, on_close
